#
# spec file for package aisleriot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aisleriot
Version:        3.22.32
Release:        1.1
Summary:        Solitaire Card Games for GNOME
License:        GPL-3.0-or-later
URL:            https://wiki.gnome.org/Apps/Aisleriot
Source0:        aisleriot-%{version}.tar.zst

BuildRequires:  distribution-release
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  meson >= 0.49
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gobject-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.18.0
BuildRequires:  pkgconfig(guile-3.0)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
Requires:       guile

%description
Aisleriot is a compilation of 80 different solitaire card games.

%package themes
Summary:        Extra themes for the Aisleriot solitaire card game program
Requires:       %{name} = %{version}
Enhances:       %{name}
BuildArch:      noarch

%description themes
Aisleriot is a compilation of 80 different solitaire card games.

This package provides extra themes for Aisleriot.

%lang_package

%prep
%autosetup -p1

%build
%meson \
    -Dtheme_kde=false
%meson_build

%install
%meson_install
%fdupes -s %{buildroot}%{_datadir}/help
%suse_update_desktop_file -N "AisleRiot" -G "Solitaire" sol
%find_lang %{name} %{?no_lang_C}

%files
%license COPYING.GFDL
%doc AUTHORS README.md
%doc %{_datadir}/help/C/aisleriot/
%{_bindir}/sol
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/sol.metainfo.xml
%{_datadir}/applications/sol.desktop
%{_datadir}/aisleriot/
%dir %{_libdir}/aisleriot
%dir %{_libdir}/aisleriot/guile
%dir %{_libdir}/aisleriot/guile/*
%dir %{_libdir}/aisleriot/guile/*/aisleriot
%{_libdir}/aisleriot/guile/*/aisleriot/api.go
%{_libdir}/aisleriot/guile/*/*.go
%if "%{_libdir}" != "%{_libexecdir}"
%dir %{_libexecdir}/aisleriot
%endif
%{_libexecdir}/aisleriot/ar-cards-renderer
%{_datadir}/glib-2.0/schemas/org.gnome.Patience.WindowState.gschema.xml
%{_datadir}/icons/hicolor/*/apps/gnome-aisleriot*
%{_datadir}/icons/hicolor/*/apps/gnome-freecell.*
%{_mandir}/man?/sol*%{ext_man}
# Kind of ugly to own the valgrind directory, but the other solutions (a dep on
# valgrind, a subpackage, etc.) are not worth it
%dir %{_libdir}/valgrind
%{_libdir}/valgrind/aisleriot.supp
# Exclude files that are in themes
%exclude %{_datadir}/aisleriot/cards/anglo.svgz
%exclude %{_datadir}/aisleriot/cards/ornamental.svgz

%files themes
%{_datadir}/aisleriot/cards/anglo.svgz
%{_datadir}/aisleriot/cards/ornamental.svgz

%files lang -f aisleriot.lang

%changelog
* Tue May 14 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.22.32:
  + Fixes and optimisations.
* Thu Mar 28 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.22.31:
  + Cards: Add multiple new card decks.
  + Updated translations.
* Thu Oct 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Replace lsb-release with distribution-release BuildRequires:
  aisleriot meson setup uses /etc/os-release to determine
  distribution.
* Mon Sep 25 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.22.30:
  + Revert "game: Provide a clean environment for each game"
    (glgo#GNOME/aisleriot#961).
* Tue May  2 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.22.29:
  + Updated translations.
* Mon Dec  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.22.27:
  + theme: qsvg: Flush surface before drawing to it with qt.
  + game: Provide a clean environment for each game.
  + Updated translations.
* Mon Nov 14 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.22.26:
  + metainfo: pass validation.
  + Updated translations.
* Tue May 31 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.22.23:
  + Update card decks.
* Wed Apr 13 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.22.22
  + Add support for loading user-installed themes.
  + Fix build with guile 2.2.
  + Fix build with meson 0.60.
  + Updated translations.
- Drop 4bf6fcf5c8043adfcadd948e678cc68f150cc998.patch: fixed
  upstream.
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 4bf6fcf5c8043adfcadd948e678cc68f150cc998.patch: Fix build
  with meson 0.61.0 and newer.
* Tue Jan 18 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 3.22.20:
  + Updated translations
* Fri Dec  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.22.19:
  + Updated translations
* Wed Jun 30 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.22.17:
  + Updated translations
* Tue May 11 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.22.16:
  + Updated translations
* Tue Apr 13 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.22.15:
  + Updated translations
* Sat Jan  9 2021 Matthias Eliasson <elimat@opensuse.org>
- Update to version 2.22.14:
  + Updated translations
- Run spec-cleaner
* Thu Jul 30 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 3.22.11:
  + Support for guile-3.0
  + Updated translations.
- Remove patch:
  * add-guile-3.0-support.patch: it was fixed upstream.
- Run spec-cleaner.
* Thu Jan 16 2020 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 3.22.10:
  + Switch to the meson build system.
  + remove intltool marks from AppData file.
  + Update translations.
  + Fix reshuffling.
  + Some fixes and cleanups.
- Add patch:
  + add-guile-3.0-support.patch: Allows building with Guile 3.0.
- Switch download link, as release is not on download.gnome.org
- New build requires: gcc-c++, meson and pkgconfig(libxml-2.0)
- Remove no longer needed dependencies: intltool
- Switch to meson build system, build with the defaults and remove
  hack for configure script
- Install README.md
- Don't install ChangeLog anymore, as it got removed
- sol.appdata.xml was renamed to sol.metainfo.xml
* Wed Sep 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.22.9:
  + build: Fix ChangeLog rule to work on a git worktree.
  + Updated translations.
- Use modern macros.
- Update URL.
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.22.8:
  + Drop compatibility code for ancient GTK versions.
  + gresource: Don't use a separate prefix for the help-overlay.
  + build: Require GTK 3.18.
  + Add Keyboard Shortcuts overlay.
  + Consistently use org.gnome.aisleriot app id.
  + Consistently capitalize AisleRiot.
  + Remove app menu.
  + build: Fix --enable-debug-ui help.
  + Updated translations.
* Fri Nov  9 2018 bjorn.lie@gmail.com
- Update to version 3.22.7:
  + Updated translations.
* Wed Sep 12 2018 antoine.belvire@opensuse.org
- Update to version 3.22.6:
  + Updated translations.
- Remove lang package from recommended packages as it already
  supplements main package (same effect, it's redundant).
* Mon Jun  4 2018 bjorn.lie@gmail.com
- Drop pkgconfig(gconf-2.0) BuildRequires and gconf_schemas_prereq
  macro, following this: pass with-platform=gtk-only and
  with-gtk=3.0 to configure. No longer depend on obsolete gconf2.
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.22.5:
  + Bugs fixed: bgo#779434.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Oct 31 2017 luc14n0@linuxmail.org
- Update to version 3.22.4:
  + Updated translations.
- Drop %%glib2_gsettings_schema_*, %%desktop_database_ and
  %%icon_theme_cache_* post/postun/requires macros: functionality
  now covered by file triggers.
- Pass --enable-sound to configure to ensure sound is enabled.
* Tue Oct  3 2017 jengelh@inai.de
- Update package descriptions.
* Mon Sep 11 2017 luc14n0@linuxmail.org
- Update to version 3.22.3:
  + Updated translations.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 3.22.2:
  + build:
  - Build against guile 2.2 by default.
  - Print guile version on configure summary.
  + Install appstream metadata to /usr/share/metainfo.
  + Updated translations.
* Tue Apr 25 2017 dimstar@opensuse.org
- Fix build with different versions of guile than 2.0.
* Mon Nov  7 2016 dimstar@opensuse.org
- Update to version 3.22.1:
  + Prefer CSS cursors (bgo#772966).
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + themes: qt:
  - Port to qt5.
  - Fix KDE card theme path on fedora.
  - Fix rsvg includes.
  + build:
  - More warnings.
  - Fix configure debug check.
  + docs: man: Update man page.
  + Add Language headers to po files.
  + Updated translations.
* Thu May 12 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Updated appdata to latest specification.
  + build: Treat precious variables correctly.
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.1:
  + sol: Fails to start when running with gtk+ 3.19 but compiled
    against earlier version.
  + board: Try to work with newer gtk+.
  + all: Remove clutter leftovers.
* Sat Mar 19 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + sol: Don't accept non-UTF-8 locale.
  + guile:
  - Remove export for '_'.
  - Set the default port encoding to UTF-8.
  - Use guile builtin gettext.
  + conf: Fix storing window size.
  + build: Don't fail configure if gconf macros are not installed.
  + Update appdata.
  + Fix the type of ar_card_theme_qsvg_get_card_aspect.
  + Updated translations.
* Fri Jan 29 2016 dimstar@opensuse.org
- Drop appdata-tools BuildRequires: the build not longer validates
  appdata.xml and upstream is responsible for its validity.
* Mon Nov  9 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Updated translations.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + New games: Hamilton, Wall.
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + sol:
  - Don't call deprecated function g_type_init (bgo#747885).
  - Suppress deprecated object property warnings (bgo#749195).
  + help: Fix typos in documentation (bgo#746671).
  + wall: Add new game 'Wall' (bgo#747583).
  + hamilton: Add new 'Hamilton' game.
  + Updated translations.
* Mon May 11 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + icon: provide a symbolic variant of the app icon (bgo#747007).
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Thu Apr 16 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Bugs fixed: bgo#702951, bgo#735242, deb#777507.
  + Updated translations.
* Mon Jan 26 2015 dimstar@opensuse.org
- Update to version 3.15.0:
  + build: Distcheck with all card theme formats enabled.
  + Add QtSvg based renderer for KDE card themes.
  + Plug some memory leaks.
  + Bugs fixed: bgo#739567, bgo#659623.
  + Updated translations.
* Fri Nov 14 2014 dimstar@opensuse.org
- Drop openSUSE-release BuildRequires: as this package gets a daily
  update to represent the build version, aisleriot is being rebuilt
  for no reason everyday.
- Hackup configure to fallback to 'opensuse' as release when no
  /etc/os-release can be found.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Revert "build: Run configure script with bash".
  + build: Require bash to run configure.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Fix logo on about dialog (bgo#737674).
  + Updated translations.
* Sun Sep 21 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + svg: Allow big SVG card themes to load.
  + Correct the appdata file name.
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + board: Use nicer hand cursors.
  + Remove theme install code.
  + Remove PackageKit catalogue support (bgo#672604).
  + Updated translations.
- Add appdata-tools BuildRequires: new dependency to validate the
  .appdata file.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + build: Remove GNOME_COMMON_INIT (bgo#729400).
  + board: Use nicer hand cursors.
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Build fixes (bgo#715120, bgo#726780).
  + Games fixes (bgo#677197).
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + board: Make the moving cards window native. Forcing the moving
    cards subwindow to be native works around the window being
    invisible due to the gtk drawing changes (bgo#702951).
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Build fixes.
  + Updated translations.
* Sun Jul 28 2013 zaitor@opensuse.org
- Update to version 3.9.90:
  + Many game improvements.
  + New card decks.
  + Build fixes.
  + Updated translations.
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
- Replace dummy-release BuildRequires with suse-release: configure
  uses /etc/os-release to identify the distribution and do some
  sane defaults based on this.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Bugs fixed: bgo#588260, bgo#679715, bgo#688525, bgo#695086,
    bgo#695087, bgo#695102.
  + Updated translations.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Updated translations.
* Wed Oct 17 2012 zaitor@opensuse.org
- Add fdupes buildrequires, and use fdupes macro to get rid of
  duplicate help files.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Updated translations.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Fix help link
  + Updated translations.
* Sun Aug 19 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Many games fixes
  + Updated translations.
* Mon Jun  4 2012 dimstar@opensuse.org
- Update to version 3.5.0:
  + Build fixes.
  + Many games fixes.
  + Updated translations.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0.1:
  + Updated translations.
- Remove sed hack in %%prep for missing translations: fixed
  upstream.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
- Note that we keep the sed hack in %%prep for missing translations:
  things are still broken, unfortunately.
* Mon Mar 26 2012 vuntz@opensuse.org
- Remove hack to find localized help: this has been fixed in
  find-lang.sh.
* Sun Feb 26 2012 vuntz@opensuse.org
- Change itstool BuildRequires to yelp-tools: this is really what
  is needed for build.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.2:
  + Misc improvements and bug fixes
  + Updated translations.
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Drop gnome-freecell.png source file and stop manually installing
  a 256x256 icon: it's done upstream now.
- Add sed hack in %%prep to work around a bug in yelp-tools that
  caused this tarball to not contain all help translations.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 3.3.1:
  + Aisleriot now requires guile >= 2.0
  + Many improvements and bug fixes
  + Updated translations.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Remove pkgconfig(ice) and pkgconfig(sm) BuildRequires: removed
  upstream.
- Really drop aisleriot-automagic-guile.patch.
- Drop aisleriot-fix-freecell-exception.patch: fixed upstream.
* Mon Nov 28 2011 malcolmlewis@opensuse.org
- Add aisleriot-fix-freecell-exception.patch: Fix trying to make
  the first move in a freecell game generates an exception
  (bnc#730053, bgo#649730).
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 3.3.0:
  + Change card theme format
  + Many game fixes
  + Updated translations.
- Drop aisleriot-automagic-guile.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh as
  we don't carry any patch requiring this anymore.
- Pass --with-guile=auto to configure.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 3.2.2:
  + Dist missing sound files
* Sun Nov 13 2011 malcolmlewis@opensuse.org
- Add missing guile Requires: game will not start without it
  (bnc#730053).
* Tue Oct 18 2011 malcolmlewis@opensuse.org
- Skip aisleriot-automagic-guile.patch when building on 11.4
  since the guile version in 11.4 is not recent enough to
  require the patch.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Minor bugfixes
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Update card theme install info for debian (bgo#659997)
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Distribute a copy of the LGPL
  + Update card theme install info for opensuse and ubuntu
    (bgo#648601)
  + Update card theme install info for ubuntu (bgo#648601)
  + Fix the build with the 'file' help method (bgo#656967)
  + Build ghelp with yelp-tools instead of gnome-doc-utils
    (bgo#657683)
  + Fix game restart (bgo#657735)
  + Updated translations.
- Drop aisleriot-theme-install.patch: fixed upstream.
- Change gnome-doc-utils-devel BuildRequires to itstool, following
  the change in help build system.
- Remove --disable-scrollkeeper configure option: it doesn't exist
  anymore.
- Manually list the translated help documents as %%find_lang needs
  to support the new XDG help system first.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Sun Sep  4 2011 vuntz@opensuse.org
- Add aisleriot-automagic-guile.patch: make detection of guile
  version automatic by default, to avoid having to specify it in
  configure.
- Add gnome-common BuildRequires and call to gnome-autogen.sh for
  above patch.
* Wed Aug 24 2011 badshah400@gmail.com
- Added icon of size 256x256 for freecell (bnc#713902)
* Tue Aug 16 2011 dimstar@opensuse.org
- Update to version 3.1.1:
  + bgo#325039: Add Aunt Mary back
  + Updated translations.
* Fri Jul  1 2011 vuntz@opensuse.org
- Split some card themes in aisleriot-themes, to make the main
  package smaller.
- Add aisleriot-theme-install.patch to let aisleriot know about the
  right name of the package for extra themes.
* Wed Jun 15 2011 vuntz@opensuse.org
- New package (version 3.1.0). Aisleriot was split from the
  gnome-games tarball.
